==> helm-annotations-3.5.0-sources.jar: io/dekorate/helm/config/AnnotationBuilder.java <==
package io.dekorate.helm.config;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;

 /**
  * Generated
  */
public class AnnotationBuilder extends AnnotationFluentImpl<AnnotationBuilder> implements VisitableBuilder<Annotation,AnnotationBuilder>{
  public AnnotationBuilder() {
    this(false);
  }
  public AnnotationBuilder(Boolean validationEnabled) {
    this(new Annotation(), validationEnabled);
  }
  public AnnotationBuilder(AnnotationFluent<?> fluent) {
    this(fluent, false);
  }
  public AnnotationBuilder(AnnotationFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new Annotation(), validationEnabled);
  }
  public AnnotationBuilder(AnnotationFluent<?> fluent,Annotation instance) {
    this(fluent, instance, false);
  }
  public AnnotationBuilder(AnnotationFluent<?> fluent,Annotation instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withKey(instance.getKey()); 
    fluent.withValue(instance.getValue()); 
    this.validationEnabled = validationEnabled; 
  }
  public AnnotationBuilder(Annotation instance) {
    this(instance,false);
  }
  public AnnotationBuilder(Annotation instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withKey(instance.getKey()); 
    this.withValue(instance.getValue()); 
    this.validationEnabled = validationEnabled; 
  }
  AnnotationFluent<?> fluent;
  Boolean validationEnabled;
  public EditableAnnotation build() {
    EditableAnnotation buildable = new EditableAnnotation(fluent.getKey(),fluent.getValue());
    return buildable;
  }
  
}

==> helm-annotations-4.0.1-sources.jar: io/dekorate/helm/config/AnnotationBuilder.java <==
package io.dekorate.helm.config;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;

 /**
  * Generated
  */
public class AnnotationBuilder extends AnnotationFluent<AnnotationBuilder> implements VisitableBuilder<Annotation,AnnotationBuilder>{
  public AnnotationBuilder() {
    this(false);
  }
  public AnnotationBuilder(Boolean validationEnabled) {
    this(new Annotation(), validationEnabled);
  }
  public AnnotationBuilder(AnnotationFluent<?> fluent) {
    this(fluent, false);
  }
  public AnnotationBuilder(AnnotationFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new Annotation(), validationEnabled);
  }
  public AnnotationBuilder(AnnotationFluent<?> fluent,Annotation instance) {
    this(fluent, instance, false);
  }
  public AnnotationBuilder(AnnotationFluent<?> fluent,Annotation instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new Annotation());

    if (instance != null) {
      fluent.withKey(instance.getKey());
      fluent.withValue(instance.getValue());
    }
    this.validationEnabled = validationEnabled; 
  }
  public AnnotationBuilder(Annotation instance) {
    this(instance,false);
  }
  public AnnotationBuilder(Annotation instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new Annotation());

    if (instance != null) {
      this.withKey(instance.getKey());
      this.withValue(instance.getValue());
    }
    this.validationEnabled = validationEnabled; 
  }
  AnnotationFluent<?> fluent;
  Boolean validationEnabled;
  public EditableAnnotation build() {
    EditableAnnotation buildable = new EditableAnnotation(fluent.getKey(),fluent.getValue());
    return buildable;
  }
  
}
